# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class TestrunresultResultSummaryCounts(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'total': 'str',
        '_pass': 'str',
        'warning': 'str',
        'fail': 'str',
        'skip': 'str'
    }

    attribute_map = {
        'total': 'total',
        '_pass': 'pass',
        'warning': 'warning',
        'fail': 'fail',
        'skip': 'skip'
    }

    def __init__(self, total=None, _pass=None, warning=None, fail=None, skip=None):  # noqa: E501
        """TestrunresultResultSummaryCounts - a model defined in Swagger"""  # noqa: E501
        self._total = None
        self.__pass = None
        self._warning = None
        self._fail = None
        self._skip = None
        self.discriminator = None
        if total is not None:
            self.total = total
        if _pass is not None:
            self._pass = _pass
        if warning is not None:
            self.warning = warning
        if fail is not None:
            self.fail = fail
        if skip is not None:
            self.skip = skip

    @property
    def total(self):
        """Gets the total of this TestrunresultResultSummaryCounts.  # noqa: E501

        The total number of tests.  # noqa: E501

        :return: The total of this TestrunresultResultSummaryCounts.  # noqa: E501
        :rtype: str
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this TestrunresultResultSummaryCounts.

        The total number of tests.  # noqa: E501

        :param total: The total of this TestrunresultResultSummaryCounts.  # noqa: E501
        :type: str
        """

        self._total = total

    @property
    def _pass(self):
        """Gets the _pass of this TestrunresultResultSummaryCounts.  # noqa: E501

        The number of tests that pass.  # noqa: E501

        :return: The _pass of this TestrunresultResultSummaryCounts.  # noqa: E501
        :rtype: str
        """
        return self.__pass

    @_pass.setter
    def _pass(self, _pass):
        """Sets the _pass of this TestrunresultResultSummaryCounts.

        The number of tests that pass.  # noqa: E501

        :param _pass: The _pass of this TestrunresultResultSummaryCounts.  # noqa: E501
        :type: str
        """

        self.__pass = _pass

    @property
    def warning(self):
        """Gets the warning of this TestrunresultResultSummaryCounts.  # noqa: E501

        The number of tests that raise a warning.  # noqa: E501

        :return: The warning of this TestrunresultResultSummaryCounts.  # noqa: E501
        :rtype: str
        """
        return self._warning

    @warning.setter
    def warning(self, warning):
        """Sets the warning of this TestrunresultResultSummaryCounts.

        The number of tests that raise a warning.  # noqa: E501

        :param warning: The warning of this TestrunresultResultSummaryCounts.  # noqa: E501
        :type: str
        """

        self._warning = warning

    @property
    def fail(self):
        """Gets the fail of this TestrunresultResultSummaryCounts.  # noqa: E501

        The number of tests that fail.  # noqa: E501

        :return: The fail of this TestrunresultResultSummaryCounts.  # noqa: E501
        :rtype: str
        """
        return self._fail

    @fail.setter
    def fail(self, fail):
        """Sets the fail of this TestrunresultResultSummaryCounts.

        The number of tests that fail.  # noqa: E501

        :param fail: The fail of this TestrunresultResultSummaryCounts.  # noqa: E501
        :type: str
        """

        self._fail = fail

    @property
    def skip(self):
        """Gets the skip of this TestrunresultResultSummaryCounts.  # noqa: E501

        The number of tests that are skipped.  # noqa: E501

        :return: The skip of this TestrunresultResultSummaryCounts.  # noqa: E501
        :rtype: str
        """
        return self._skip

    @skip.setter
    def skip(self, skip):
        """Sets the skip of this TestrunresultResultSummaryCounts.

        The number of tests that are skipped.  # noqa: E501

        :param skip: The skip of this TestrunresultResultSummaryCounts.  # noqa: E501
        :type: str
        """

        self._skip = skip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TestrunresultResultSummaryCounts, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestrunresultResultSummaryCounts):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
