# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `X-Firewall-Api-Key` for all the firewall methods and `rime-api-key` for all other methods.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CustommonitorsNameBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'firewall_id': 'RimeUUID',
        'artifact_identifier': 'MonitorArtifactIdentifier',
        'aggregation': 'MonitorAggregation',
        'transform': 'MonitorTransform',
        'threshold': 'MonitorThreshold',
        'notify': 'bool'
    }

    attribute_map = {
        'firewall_id': 'firewallId',
        'artifact_identifier': 'artifactIdentifier',
        'aggregation': 'aggregation',
        'transform': 'transform',
        'threshold': 'threshold',
        'notify': 'notify'
    }

    def __init__(self, firewall_id=None, artifact_identifier=None, aggregation=None, transform=None, threshold=None, notify=None):  # noqa: E501
        """CustommonitorsNameBody - a model defined in Swagger"""  # noqa: E501
        self._firewall_id = None
        self._artifact_identifier = None
        self._aggregation = None
        self._transform = None
        self._threshold = None
        self._notify = None
        self.discriminator = None
        if firewall_id is not None:
            self.firewall_id = firewall_id
        if artifact_identifier is not None:
            self.artifact_identifier = artifact_identifier
        if aggregation is not None:
            self.aggregation = aggregation
        if transform is not None:
            self.transform = transform
        if threshold is not None:
            self.threshold = threshold
        if notify is not None:
            self.notify = notify

    @property
    def firewall_id(self):
        """Gets the firewall_id of this CustommonitorsNameBody.  # noqa: E501


        :return: The firewall_id of this CustommonitorsNameBody.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._firewall_id

    @firewall_id.setter
    def firewall_id(self, firewall_id):
        """Sets the firewall_id of this CustommonitorsNameBody.


        :param firewall_id: The firewall_id of this CustommonitorsNameBody.  # noqa: E501
        :type: RimeUUID
        """

        self._firewall_id = firewall_id

    @property
    def artifact_identifier(self):
        """Gets the artifact_identifier of this CustommonitorsNameBody.  # noqa: E501


        :return: The artifact_identifier of this CustommonitorsNameBody.  # noqa: E501
        :rtype: MonitorArtifactIdentifier
        """
        return self._artifact_identifier

    @artifact_identifier.setter
    def artifact_identifier(self, artifact_identifier):
        """Sets the artifact_identifier of this CustommonitorsNameBody.


        :param artifact_identifier: The artifact_identifier of this CustommonitorsNameBody.  # noqa: E501
        :type: MonitorArtifactIdentifier
        """

        self._artifact_identifier = artifact_identifier

    @property
    def aggregation(self):
        """Gets the aggregation of this CustommonitorsNameBody.  # noqa: E501


        :return: The aggregation of this CustommonitorsNameBody.  # noqa: E501
        :rtype: MonitorAggregation
        """
        return self._aggregation

    @aggregation.setter
    def aggregation(self, aggregation):
        """Sets the aggregation of this CustommonitorsNameBody.


        :param aggregation: The aggregation of this CustommonitorsNameBody.  # noqa: E501
        :type: MonitorAggregation
        """

        self._aggregation = aggregation

    @property
    def transform(self):
        """Gets the transform of this CustommonitorsNameBody.  # noqa: E501


        :return: The transform of this CustommonitorsNameBody.  # noqa: E501
        :rtype: MonitorTransform
        """
        return self._transform

    @transform.setter
    def transform(self, transform):
        """Sets the transform of this CustommonitorsNameBody.


        :param transform: The transform of this CustommonitorsNameBody.  # noqa: E501
        :type: MonitorTransform
        """

        self._transform = transform

    @property
    def threshold(self):
        """Gets the threshold of this CustommonitorsNameBody.  # noqa: E501


        :return: The threshold of this CustommonitorsNameBody.  # noqa: E501
        :rtype: MonitorThreshold
        """
        return self._threshold

    @threshold.setter
    def threshold(self, threshold):
        """Sets the threshold of this CustommonitorsNameBody.


        :param threshold: The threshold of this CustommonitorsNameBody.  # noqa: E501
        :type: MonitorThreshold
        """

        self._threshold = threshold

    @property
    def notify(self):
        """Gets the notify of this CustommonitorsNameBody.  # noqa: E501

        Whether to notify when the monitor is triggered.  # noqa: E501

        :return: The notify of this CustommonitorsNameBody.  # noqa: E501
        :rtype: bool
        """
        return self._notify

    @notify.setter
    def notify(self, notify):
        """Sets the notify of this CustommonitorsNameBody.

        Whether to notify when the monitor is triggered.  # noqa: E501

        :param notify: The notify of this CustommonitorsNameBody.  # noqa: E501
        :type: bool
        """

        self._notify = notify

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustommonitorsNameBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustommonitorsNameBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
